@@ -19,6 +19,7 @@ from localstack.aws.api import (
     handler,
 )
 from localstack.aws.api.dynamodb import (
+    BatchExecuteStatementOutput,
     BatchGetItemOutput,
     BatchGetRequestMap,
     BatchWriteItemInput,
@@ -37,6 +38,8 @@ from localstack.aws.api.dynamodb import (
     DynamodbApi,
     ExecuteStatementInput,
     ExecuteStatementOutput,
+    ExecuteTransactionInput,
+    ExecuteTransactionOutput,
     GetItemInput,
     GetItemOutput,
     GlobalTableAlreadyExistsException,
@@ -47,6 +50,7 @@ from localstack.aws.api.dynamodb import (
     ListTablesOutput,
     ListTagsOfResourceOutput,
     NextTokenString,
+    PartiQLBatchRequest,
     PositiveIntegerObject,
     ProvisionedThroughputExceededException,
     PutItemInput,
@@ -419,6 +423,12 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
         if "StreamSpecification" in table_definitions:
             create_dynamodb_stream(table_definitions, table_description.get("LatestStreamLabel"))
 
+        if "TableClass" in table_definitions:
+            table_class = table_description.pop("TableClass", None) or table_definitions.pop(
+                "TableClass"
+            )
+            table_description["TableClassSummary"] = {"TableClass": table_class}
+
         tags = table_definitions.pop("Tags", [])
         if tags:
             table_arn = table_description["TableArn"]
@@ -475,6 +485,10 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
             for key in ["TableId", "SSEDescription"]:
                 if table_definitions.get(key):
                     result.get("Table", {})[key] = table_definitions[key]
+            if "TableClass" in table_definitions:
+                result.get("Table", {})["TableClassSummary"] = {
+                    "TableClass": table_definitions["TableClass"]
+                }
 
         return result
 
@@ -489,8 +503,20 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
             is_no_update_error = (
                 e.code == "ValidationException" and "Nothing to update" in e.message
             )
-            if is_no_update_error and update_table_input.get("ReplicaUpdates"):
-                table_name = update_table_input.get("TableName")
+            if not is_no_update_error or not list(
+                {"TableClass", "ReplicaUpdates"} & set(update_table_input.keys())
+            ):
+                raise
+
+            table_name = update_table_input.get("TableName")
+
+            if update_table_input.get("TableClass"):
+                table_definitions = DynamoDBRegion.get().table_definitions.setdefault(
+                    table_name, {}
+                )
+                table_definitions["TableClass"] = update_table_input.get("TableClass")
+
+            if update_table_input.get("ReplicaUpdates"):
                 # update local table props (replicas)
                 table_properties = DynamoDBRegion.get().table_properties
                 table_properties[table_name] = table_props = table_properties.get(table_name) or {}
@@ -509,10 +535,10 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
                             table_props["Replicas"] = [
                                 r for r in replicas if r.get("RegionName") != region
                             ]
-                # update response content
-                schema = SchemaExtractor.get_table_schema(table_name)
-                return UpdateTableOutput(TableDescription=schema["Table"])
-            raise
+
+            # update response content
+            schema = SchemaExtractor.get_table_schema(table_name)
+            return UpdateTableOutput(TableDescription=schema["Table"])
 
         if "StreamSpecification" in update_table_input:
             create_dynamodb_stream(
@@ -778,6 +804,13 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
     ) -> TransactGetItemsOutput:
         return self.forward_request(context)
 
+    @handler("ExecuteTransaction", expand=False)
+    def execute_transaction(
+        self, context: RequestContext, execute_transaction_input: ExecuteTransactionInput
+    ) -> ExecuteTransactionOutput:
+        result = self.forward_request(context)
+        return result
+
     @handler("ExecuteStatement", expand=False)
     def execute_statement(
         self,
@@ -1129,6 +1162,15 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
                 i += 1
         return records
 
+    def batch_execute_statement(
+        self,
+        context: RequestContext,
+        statements: PartiQLBatchRequest,
+        return_consumed_capacity: ReturnConsumedCapacity = None,
+    ) -> BatchExecuteStatementOutput:
+        result = self.forward_request(context)
+        return result
+
     def prepare_batch_write_item_records(
         self,
         request_items,
