@@ -6,8 +6,11 @@ from moto.ec2.exceptions import InvalidVpcEndPointIdError
 
 from localstack.aws.api import RequestContext, handler
 from localstack.aws.api.ec2 import (
+    AvailabilityZone,
     Boolean,
     CurrencyCodeValues,
+    DescribeAvailabilityZonesRequest,
+    DescribeAvailabilityZonesResult,
     DescribeReservedInstancesOfferingsRequest,
     DescribeReservedInstancesOfferingsResult,
     DescribeReservedInstancesRequest,
@@ -41,6 +44,34 @@ from localstack.utils.strings import long_uid
 
 
 class Ec2Provider(Ec2Api, ABC):
+    @handler("DescribeAvailabilityZones", expand=False)
+    def describe_availability_zones(
+        self,
+        context: RequestContext,
+        describe_availability_zones_request: DescribeAvailabilityZonesRequest,
+    ) -> DescribeAvailabilityZonesResult:
+        backend = ec2_backends.get(context.region)
+
+        availability_zones = []
+        zone_names = describe_availability_zones_request.get("ZoneNames")
+        if zone_names:
+            for zone in zone_names:
+                zone_detail = backend.get_zone_by_name(zone)
+                if zone_detail:
+                    availability_zones.append(
+                        AvailabilityZone(
+                            State="available",
+                            Messages=[],
+                            RegionName=zone_detail.region_name,
+                            ZoneName=zone_detail.name,
+                            ZoneId=zone_detail.zone_id,
+                        )
+                    )
+
+            return DescribeAvailabilityZonesResult(AvailabilityZones=availability_zones)
+
+        return call_moto(context)
+
     @handler("DescribeReservedInstancesOfferings", expand=False)
     def describe_reserved_instances_offerings(
         self,
